Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports System.Windows.Forms
Imports System.IO
Imports ColorCode
Imports SelectPdf

Namespace SelectPdf.Samples
    Partial Public Class PdfTemplates
        Inherits Form

        Private Sub BtnCreatePdf_Click(sender As Object, e As EventArgs) _
            Handles BtnCreatePdf.Click
            Cursor = Cursors.WaitCursor
            Dim file As String = "Document.pdf"

            Try
                ' create a new pdf document
                Dim doc As New PdfDocument()

                ' create a new pdf font
                Dim font As PdfFont = doc.AddFont(PdfStandardFont.Helvetica)
                font.Size = 24

                ' add a new page to the document
                Dim page As PdfPage = doc.AddPage()

                ' create a new text element and add it to the page
                Dim text As New PdfTextElement(0, 0, Helper.SomeLongText(), font)
                page.Add(text)

                ' get image path
                Dim imgFile As String = AppDomain.CurrentDomain.BaseDirectory + _
                    "/../../files/logo.png"

                ' add a template containing an image
                ' the image should repeat on all pdf pages automatically
                Dim template1 As PdfTemplate = doc.AddTemplate(New RectangleF(100, 0, 400, 150))
                Dim img1 As New PdfImageElement(0, 0, imgFile)
                template1.Add(img1)

                ' add another template containing an image behind the existing page elements
                ' (under the text) the image should repeat on all pdf pages automatically
                Dim template2 As PdfTemplate = doc.AddTemplate(New RectangleF(100, 200, 400, 150))
                template2.Background = True
                Dim img2 As New PdfImageElement(0, 0, imgFile)
                template2.Add(img2)

                ' save pdf document
                doc.Save(file)

                ' close pdf document
                doc.Close()
            Catch ex As Exception
                MessageBox.Show([String].Format("Error: {0}", ex.Message), "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
                Return
            Finally
                Cursor = Cursors.Arrow
            End Try

            ' open generated pdf
            Try
                System.Diagnostics.Process.Start(file)
            Catch
                MessageBox.Show("Could not open generated pdf document", "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
            End Try
        End Sub

        Public Sub New()
            InitializeComponent()

            Try
                ' display highlighted sample code
                Dim code As String = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory + _
                                                      "/../../" + "PdfTemplates.vb")
                WBSampleCode.DocumentText = New CodeColorizer().Colorize(code, Languages.VbDotNet)
            Catch
                WBSampleCode.DocumentText = "Sample code not available"
            End Try
        End Sub

    End Class
End Namespace
